@@ -1,2 +1,2 @@
 from py_order_utils.model.model import LimitOrder, LimitOrderData, MarketOrderData, MarketOrder
-from py_order_utils.model.signatures import EOA, CONTRACT, POLY_PROXY
+from py_order_utils.model.signatures import EOA, CONTRACT, POLY_PROXY, POLY_GNOSIS_SAFE
